# Zeus the Investigator
A pure python program that checks if a site is online/offline at the moment.

#### **USAGE**
```powershell
$ zeus -u <first_url> -u <second_url> -c <cooldown(in secs. default=3)>
```

# Installation
## Manual Installation
**Note:** *You will need poetry for manual installation*
```bash
$ pip install poetry
```

1. Download or clone the repository.
```git
$ git clone https://github.com/777advait/Zeus-The-Investigator
```

2. Install the project by running the following command in the root of the directory.
``` bash
$ poetry install
```


## PyPi Installation
```bash
$ pip install ZeusTheInvestigator
```